==> libxkbcommon-doc-1.12.0-3-x86_64.pkg.tar.zst: usr/share/doc/libxkbcommon/html/search/all_15.js <==
var searchData=
[
  ['malformed_20number_20literal_0',['XKB-034 – Malformed number literal',['../error-index.html#XKB-034',1,'']]],
  ['map_1',['map',['../keymap-text-format-v1-v2.html#modmap-statement',1,'Real Modifier map'],['../keymap-text-format-v1-v2.html#set-real-mod-map',1,'Setting the real modifier map'],['../keymap-text-format-v1-v2.html#set-virtual-mod-map',1,'Setting the virtual modifier map']]],
  ['map_20entry_2',['XKB-266 – Conflicting key type map entry',['../error-index.html#XKB-266',1,'']]],
  ['map_20statements_3',['LED map statements',['../keymap-text-format-v1-v2.html#indicator-effect',1,'']]],
  ['mask_4',['XKB-060 – Unsupported modifier mask',['../error-index.html#XKB-060',1,'']]],
  ['masks_5',['Avoid using numeric modifier masks',['../keymap-text-format-v1-v2.html#avoid-using-numeric-modifier-masks',1,'']]],
  ['mean_6',['What does … mean?',['../faq.html#what-does--mean',1,'']]],
  ['mechanism_7',['The include mechanism',['../keymap-text-format-v1-v2.html#xkb-include',1,'']]],
  ['merge_20modes_8',['Merge modes',['../keymap-text-format-v1-v2.html#merge-mode-def',1,'']]],
  ['merge_20modes_9',['Example: merge modes',['../keymap-text-format-v1-v2.html#example-merge-modes',1,'']]],
  ['merging_20groups_10',['XKB-893 – Conflicting key type merging groups',['../error-index.html#XKB-893',1,'']]],
  ['message_11',['Message',['../keymap-text-format-v1-v2.html#message',1,'Message'],['../todo.html#_todo000019',1,'Message']]],
  ['missing_20default_20section_12',['XKB-433 – Missing default section',['../error-index.html#XKB-433',1,'']]],
  ['missing_20symbols_20group_20name_20index_13',['XKB-903 – Missing symbols group name index',['../error-index.html#XKB-903',1,'']]],
  ['model_14',['model',['../structxkb__rule__names.html#a1c897b49b49c7cd495db4a424bd27265',1,'xkb_rule_names']]],
  ['modes_15',['modes',['../keymap-text-format-v1-v2.html#example-merge-modes',1,'Example: merge modes'],['../keymap-text-format-v1-v2.html#merge-mode-def',1,'Merge modes']]],
  ['modifier_16',['modifier',['../error-index.html#XKB-123',1,'XKB-123 – Undeclared virtual modifier'],['../error-index.html#XKB-623',1,'XKB-623 – Invalid real modifier']]],
  ['modifier_20encoding_17',['How to get the virtual modifier encoding?',['../faq.html#how-to-get-the-virtual-modifier-encoding',1,'']]],
  ['modifier_20map_18',['Real Modifier map',['../keymap-text-format-v1-v2.html#modmap-statement',1,'']]],
  ['modifier_20map_19',['modifier map',['../keymap-text-format-v1-v2.html#set-real-mod-map',1,'Setting the real modifier map'],['../keymap-text-format-v1-v2.html#set-virtual-mod-map',1,'Setting the virtual modifier map']]],
  ['modifier_20mask_20',['XKB-060 – Unsupported modifier mask',['../error-index.html#XKB-060',1,'']]],
  ['modifier_20masks_21',['Avoid using numeric modifier masks',['../keymap-text-format-v1-v2.html#avoid-using-numeric-modifier-masks',1,'']]],
  ['modifier_20names_22',['Legacy virtual modifier names',['../group__legacy-virtual-modifier-names.html',1,'']]],
  ['modifier_20step_20by_20step_23',['Example: define and use a modifier, step by step',['../keymap-text-format-v1-v2.html#example-define-and-use-a-modifier-step-by-step',1,'']]],
  ['modifiers_24',['Modifiers',['../group__state.html',1,'Consumed Modifiers'],['../faq.html#modifiers',1,'Modifiers']]],
  ['modifiers_25',['modifiers',['../keymap-text-format-v1-v2.html#canonical-and-non-canonical-modifiers',1,'Canonical and non-canonical modifiers'],['../faq.html#how-to-get-the-keys-that-trigger-modifiers',1,'How to get the keys that trigger modifiers?'],['../keymap-text-format-v1-v2.html#real-and-virtual-modifiers',1,'Real and virtual modifiers'],['../keymap-text-format-v1-v2.html#key-virtual-modifiers',1,'Virtual modifiers']]],
  ['modifiers_20actions_26',['Modifiers actions',['../keymap-text-format-v1-v2.html#modifiers-actions',1,'Modifiers actions'],['../todo.html#_todo000009',1,'Modifiers actions']]],
  ['modifiers_20and_20associated_20keysyms_27',['Usual modifiers and associated keysyms',['../keymap-text-format-v1-v2.html#usual-modifiers-keysyms',1,'']]],
  ['modifiers_20and_20leds_28',['Predefined names for common modifiers and LEDs',['../group__modifier-names.html',1,'']]],
  ['modifiers_20declaration_20and_20binding_29',['Modifiers declaration and binding',['../keymap-text-format-v1-v2.html#modifiers-declaration-and-binding',1,'']]],
  ['modifiers_20declarations_30',['Modifiers declarations',['../keymap-text-format-v1-v2.html#virtual-modifier-statements',1,'']]],
  ['modifiers_20encoding_31',['Modifiers encoding',['../keymap-text-format-v1-v2.html#modifiers-encoding',1,'']]],
  ['modifiers_20in_20key_20type_32',['XKB-971 – Undeclared modifiers in key type',['../error-index.html#XKB-971',1,'']]],
  ['modifiers_20key_20bindings_33',['Modifiers key bindings',['../keymap-text-format-v1-v2.html#modifiers-bindings',1,'']]],
  ['modifiers_20names_34',['modifiers names',['../group__real-modifier-names.html',1,'Real modifiers names'],['../group__virtual-modifier-names.html',1,'Virtual modifiers names']]],
  ['modifiers_20portability_35',['Modifiers portability',['../keymap-text-format-v1-v2.html#modifiers-portability',1,'']]],
  ['modmap_36',['modmap',['../error-index.html#XKB-800',1,'XKB-800 – Conflicting modmap'],['../todo.html#_todo000021',1,'XKB-800 – Conflicting modmap']]],
  ['modmap_20entry_37',['XKB-206 – Invalid modmap entry',['../error-index.html#XKB-206',1,'']]],
  ['multiple_20groups_38',['Multiple groups',['../keymap-text-format-v1-v2.html#key-groups',1,'']]],
  ['multiple_20groups_20at_20once_39',['XKB-700 – Multiple groups at once',['../error-index.html#XKB-700',1,'']]],
  ['my_20custom_20layout_20without_20installing_20it_40',['How do I test my custom layout without installing it?',['../faq.html#how-do-i-test-my-custom-layout-without-installing-it',1,'']]],
  ['my_20key_20combination_20to_20switch_20between_20layouts_20not_20work_41',['Why does my key combination to switch between layouts not work?',['../faq.html#why-does-my-key-combination-to-switch-between-layouts-not-work',1,'']]],
  ['my_20keyboard_20layout_20not_20work_20as_20expected_42',['Why does my keyboard layout not work as expected?',['../faq.html#why-does-my-keyboard-layout-not-work-as-expected',1,'']]],
  ['my_20keyboard_20shortcuts_20not_20work_20properly_43',['Why do my keyboard shortcuts not work properly?',['../faq.html#why-do-my-keyboard-shortcuts-not-work-properly',1,'']]],
  ['my_20layout_44',['How do I customize my layout?',['../faq.html#how-do-i-customize-my-layout',1,'']]]
];

==> libxkbcommon-doc-1.13.1-1-x86_64.pkg.tar.zst: usr/share/doc/libxkbcommon/html/search/all_15.js <==
var searchData=
[
  ['malformed_20number_20literal_0',['XKB-034 – Malformed number literal',['../error-index.html#XKB-034',1,'']]],
  ['map_1',['map',['../keymap-text-format-v1-v2.html#modmap-statement',1,'Real Modifier map'],['../keymap-text-format-v1-v2.html#set-real-mod-map',1,'Setting the real modifier map'],['../keymap-text-format-v1-v2.html#set-virtual-mod-map',1,'Setting the virtual modifier map']]],
  ['map_20entry_2',['XKB-266 – Conflicting key type map entry',['../error-index.html#XKB-266',1,'']]],
  ['map_20statements_3',['LED map statements',['../keymap-text-format-v1-v2.html#indicator-effect',1,'']]],
  ['mask_4',['XKB-060 – Unsupported modifier mask',['../error-index.html#XKB-060',1,'']]],
  ['masks_5',['Avoid using numeric modifier masks',['../keymap-text-format-v1-v2.html#avoid-using-numeric-modifier-masks',1,'']]],
  ['mean_6',['What does … mean?',['../faq.html#what-does--mean',1,'']]],
  ['mechanism_7',['mechanism',['../packaging-keyboard-layouts.html#lookup-mechanism',1,'Lookup mechanism'],['../keymap-text-format-v1-v2.html#xkb-include',1,'The include mechanism']]],
  ['merge_20modes_8',['Merge modes',['../keymap-text-format-v1-v2.html#merge-mode-def',1,'']]],
  ['merge_20modes_9',['Example: merge modes',['../keymap-text-format-v1-v2.html#example-merge-modes',1,'']]],
  ['merging_20groups_10',['XKB-893 – Conflicting key type merging groups',['../error-index.html#XKB-893',1,'']]],
  ['message_11',['Message',['../keymap-text-format-v1-v2.html#message',1,'Message'],['../todo.html#_todo000019',1,'Message']]],
  ['missing_20default_20section_12',['XKB-433 – Missing default section',['../error-index.html#XKB-433',1,'']]],
  ['missing_20symbols_20group_20name_20index_13',['XKB-903 – Missing symbols group name index',['../error-index.html#XKB-903',1,'']]],
  ['model_14',['model',['../structxkb__rule__names.html#a1c897b49b49c7cd495db4a424bd27265',1,'xkb_rule_names']]],
  ['modes_15',['modes',['../keymap-text-format-v1-v2.html#example-merge-modes',1,'Example: merge modes'],['../keymap-text-format-v1-v2.html#merge-mode-def',1,'Merge modes']]],
  ['modifier_16',['modifier',['../error-index.html#XKB-123',1,'XKB-123 – Undeclared virtual modifier'],['../error-index.html#XKB-623',1,'XKB-623 – Invalid real modifier']]],
  ['modifier_20encoding_17',['How to get the virtual modifier encoding?',['../faq.html#how-to-get-the-virtual-modifier-encoding',1,'']]],
  ['modifier_20map_18',['Real Modifier map',['../keymap-text-format-v1-v2.html#modmap-statement',1,'']]],
  ['modifier_20map_19',['modifier map',['../keymap-text-format-v1-v2.html#set-real-mod-map',1,'Setting the real modifier map'],['../keymap-text-format-v1-v2.html#set-virtual-mod-map',1,'Setting the virtual modifier map']]],
  ['modifier_20mask_20',['XKB-060 – Unsupported modifier mask',['../error-index.html#XKB-060',1,'']]],
  ['modifier_20masks_21',['Avoid using numeric modifier masks',['../keymap-text-format-v1-v2.html#avoid-using-numeric-modifier-masks',1,'']]],
  ['modifier_20names_22',['Legacy virtual modifier names',['../group__legacy-virtual-modifier-names.html',1,'']]],
  ['modifier_20step_20by_20step_23',['Example: define and use a modifier, step by step',['../keymap-text-format-v1-v2.html#example-define-and-use-a-modifier-step-by-step',1,'']]],
  ['modifiers_24',['Modifiers',['../group__state.html',1,'Consumed Modifiers'],['../faq.html#modifiers',1,'Modifiers']]],
  ['modifiers_25',['modifiers',['../keymap-text-format-v1-v2.html#canonical-and-non-canonical-modifiers',1,'Canonical and non-canonical modifiers'],['../faq.html#how-to-get-the-keys-that-trigger-modifiers',1,'How to get the keys that trigger modifiers?'],['../keymap-text-format-v1-v2.html#real-and-virtual-modifiers',1,'Real and virtual modifiers'],['../keymap-text-format-v1-v2.html#key-virtual-modifiers',1,'Virtual modifiers']]],
  ['modifiers_20actions_26',['Modifiers actions',['../keymap-text-format-v1-v2.html#modifiers-actions',1,'Modifiers actions'],['../todo.html#_todo000009',1,'Modifiers actions']]],
  ['modifiers_20and_20associated_20keysyms_27',['Usual modifiers and associated keysyms',['../keymap-text-format-v1-v2.html#usual-modifiers-keysyms',1,'']]],
  ['modifiers_20and_20leds_28',['Predefined names for common modifiers and LEDs',['../group__modifier-names.html',1,'']]],
  ['modifiers_20declaration_20and_20binding_29',['Modifiers declaration and binding',['../keymap-text-format-v1-v2.html#modifiers-declaration-and-binding',1,'']]],
  ['modifiers_20declarations_30',['Modifiers declarations',['../keymap-text-format-v1-v2.html#virtual-modifier-statements',1,'']]],
  ['modifiers_20encoding_31',['Modifiers encoding',['../keymap-text-format-v1-v2.html#modifiers-encoding',1,'']]],
  ['modifiers_20in_20key_20type_32',['XKB-971 – Undeclared modifiers in key type',['../error-index.html#XKB-971',1,'']]],
  ['modifiers_20key_20bindings_33',['Modifiers key bindings',['../keymap-text-format-v1-v2.html#modifiers-bindings',1,'']]],
  ['modifiers_20names_34',['modifiers names',['../group__real-modifier-names.html',1,'Real modifiers names'],['../group__virtual-modifier-names.html',1,'Virtual modifiers names']]],
  ['modifiers_20portability_35',['Modifiers portability',['../keymap-text-format-v1-v2.html#modifiers-portability',1,'']]],
  ['modmap_36',['modmap',['../error-index.html#XKB-800',1,'XKB-800 – Conflicting modmap'],['../todo.html#_todo000021',1,'XKB-800 – Conflicting modmap']]],
  ['modmap_20entry_37',['XKB-206 – Invalid modmap entry',['../error-index.html#XKB-206',1,'']]],
  ['multiple_20groups_38',['Multiple groups',['../keymap-text-format-v1-v2.html#key-groups',1,'']]],
  ['multiple_20groups_20at_20once_39',['XKB-700 – Multiple groups at once',['../error-index.html#XKB-700',1,'']]],
  ['multiple_20groups_20per_20key_40',['How do I define multiple groups per key?',['../faq.html#how-do-i-define-multiple-groups-per-key',1,'']]],
  ['my_20custom_20layout_20without_20installing_20it_41',['How do I test my custom layout without installing it?',['../faq.html#how-do-i-test-my-custom-layout-without-installing-it',1,'']]],
  ['my_20key_20combination_20to_20switch_20between_20layouts_20not_20work_42',['Why does my key combination to switch between layouts not work?',['../faq.html#why-does-my-key-combination-to-switch-between-layouts-not-work',1,'']]],
  ['my_20keyboard_20layout_20not_20work_20as_20expected_43',['Why does my keyboard layout not work as expected?',['../faq.html#why-does-my-keyboard-layout-not-work-as-expected',1,'']]],
  ['my_20keyboard_20shortcuts_20not_20work_20properly_44',['Why do my keyboard shortcuts not work properly?',['../faq.html#why-do-my-keyboard-shortcuts-not-work-properly',1,'']]],
  ['my_20layout_45',['How do I customize my layout?',['../faq.html#how-do-i-customize-my-layout',1,'']]]
];
